# fldpln


[![image](https://img.shields.io/pypi/v/fldpln.svg)](https://pypi.python.org/pypi/fldpln)
[![image](https://img.shields.io/conda/vn/conda-forge/fldpln.svg)](https://anaconda.org/conda-forge/fldpln)


**Flood inundation modeling and mapping using the FLDPLN model**


-   Free software: MIT License
-   Documentation: https://xingongli.github.io/fldpln
    

## Features

-   Four modules to create and map FLDPLN library
-   model module provides the FLDPLN class and methods for creating segment-based FLDPLN library
-   tile module provides functions for tiling segment-based library for parallel mapping
-   mapping module provides functions for generating special and flood event inundation maps
-   gauge module provides functions for preparing gauges for use in flood mapping
